pytest-9.0.0
=======================================

The pytest team is proud to announce the 9.0.0 release!

This release contains new features, improvements, bug fixes, and breaking changes, so users
are encouraged to take a look at the CHANGELOG carefully:

    https://docs.pytest.org/en/stable/changelog.html

For complete documentation, please visit:

    https://docs.pytest.org/en/stable/

As usual, you can upgrade from PyPI via:

    pip install -U pytest

Thanks to all of the contributors to this release:

* AD
* Aditi De
* Ali Nazzal
* Bruno Oliveira
* Charles-Meldhine Madi Mnemoi
* Clément Robert
* CoretexShadow
* Cornelius Roemer
* Eero Vaher
* Freya Bruhin
* Harsha Sai
* Hossein
* Israël Hallé
* Iwithyou2025
* James Addison
* John Litborn
* Jordan Macdonald
* Kieran Ryan
* Liam DeVoe
* Marc Mueller
* Marcos Boger
* Michał Górny
* Mulat Mekonen
* NayeemJohn
* Olivier Grisel
* Omri Golan
* Pierre Sassoulas
* Praise Tompane
* Ran Benita
* Reilly Brogan
* Samuel Gaist
* SarahPythonista
* Sorin Sbarnea
* Stu-ops
* Tanuj Rai
* bengartner
* dariomesic
* jakkdl
* karlicoss
* popododo0720
* sazsu
* slackline
* vyuroshchin
* zapl
* 🇺🇦 Sviatoslav Sydorenko (Святослав Сидоренко)


Happy testing,
The pytest Development Team
